==> wp2-be-search-dm-1.0.2-20251229.114331-1-sources.jar: com/finconsgroup/itserr/marketplace/search/dm/SearchDmApplication.java <==
package com.finconsgroup.itserr.marketplace.search.dm;

import com.finconsgroup.itserr.marketplace.search.dm.config.CatalogSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.DefaultSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.EventSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.InstitutionalPageSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.NewsSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.UserProfileSearchProperties;
import io.swagger.v3.oas.annotations.OpenAPIDefinition;
import io.swagger.v3.oas.annotations.info.Info;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.data.elasticsearch.ElasticsearchDataAutoConfiguration;
import org.springframework.boot.context.properties.EnableConfigurationProperties;

@SpringBootApplication(exclude = {ElasticsearchDataAutoConfiguration.class})
@EnableConfigurationProperties({DefaultSearchProperties.class, CatalogSearchProperties.class,
        UserProfileSearchProperties.class, InstitutionalPageSearchProperties.class,
        EventSearchProperties.class, NewsSearchProperties.class})
@OpenAPIDefinition(info = @Info(
        title = "OpenSearch Domain API",
        description = "API definition of the OpenSearch Domain Microservice",
        version = "1.0.0"
))
public class SearchDmApplication {

    public static void main(String[] args) {
        SpringApplication.run(SearchDmApplication.class, args);
    }

}

==> wp2-be-search-dm-1.8.0-sources.jar: com/finconsgroup/itserr/marketplace/search/dm/SearchDmApplication.java <==
package com.finconsgroup.itserr.marketplace.search.dm;

import com.finconsgroup.itserr.marketplace.search.dm.config.CatalogSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.DefaultSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.DiscussionSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.EventSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.InstitutionalPageSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.NewsSearchProperties;
import com.finconsgroup.itserr.marketplace.search.dm.config.UserProfileSearchProperties;
import io.swagger.v3.oas.annotations.OpenAPIDefinition;
import io.swagger.v3.oas.annotations.info.Info;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.data.elasticsearch.ElasticsearchDataAutoConfiguration;
import org.springframework.boot.context.properties.EnableConfigurationProperties;

@SpringBootApplication(exclude = {ElasticsearchDataAutoConfiguration.class})
@EnableConfigurationProperties({DefaultSearchProperties.class, CatalogSearchProperties.class,
        UserProfileSearchProperties.class, InstitutionalPageSearchProperties.class,
        EventSearchProperties.class, NewsSearchProperties.class, DiscussionSearchProperties.class})
@OpenAPIDefinition(info = @Info(
        title = "OpenSearch Domain API",
        description = "API definition of the OpenSearch Domain Microservice",
        version = "1.0.0"
))
public class SearchDmApplication {

    public static void main(String[] args) {
        SpringApplication.run(SearchDmApplication.class, args);
    }

}
